==> esATAC_1.0.2.tar.gz: esATAC/inst/doc/ATACpipe-Introduction.R <==
## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, warning=FALSE, message=FALSE)

## ----flowchart,message=FALSE,warning=FALSE-------------------------------
library(esATAC)
printMap()

## ----loading0,message=FALSE----------------------------------------------
library(esATAC)

## ----loading1,message=FALSE----------------------------------------------
options(java.parameters = "-Xmx8000m")

## ----loadingpkg,message=FALSE--------------------------------------------
library(magrittr)
library(BSgenome.Hsapiens.UCSC.hg19)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(org.Hs.eg.db)
library(R.utils)
library(magrittr)

## ----loadref, eval=TRUE--------------------------------------------------
# we use temp directiory here 
# change it to your directiory because the intermediate file may be huge
td<-tempdir()
options(atacConf=setConfigure("tmpdir",td))
options(atacConf=setConfigure("threads",8))

## ----config, eval=TRUE---------------------------------------------------
#uncomment and modify to run:
#options(atacConf=setConfigure("refdir","path/to/refdatafolder"))
#options(atacConf=setConfigure("genome","hg19"))

## ----casesingle, eval=FALSE----------------------------------------------
#  td<-tempdir()
#  options(atacConf=setConfigure("threads",4))
#  dir.create(file.path(td,"ref"))
#  # Change the refdir to your installed refdir path
#  # or it will be time comsuming to build bowtie2 index.
#  options(atacConf=setConfigure("refdir",file.path(td,"ref")))
#  options(atacConf=setConfigure("genome","hg19"))
#  bedbzfile11 <- c(
#      system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#      system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2")
#  )
#  bedbzfile12 <- c(
#      system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz"),
#      system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")
#  )
#  # for single end
#  dir.create(file.path(td,"single"))
#  options(atacConf=setConfigure("tmpdir",file.path(td,"single")))
#  conclusion1<-atacPipe(fastqInput1 = bedbzfile11,adapter1 = "CTGTCTCTTATACACATCTCCGAGCCCACGAGACTGAAG")
#  # for paired end
#  dir.create(file.path(td,"paired"))
#  options(atacConf=setConfigure("tmpdir",file.path(td,"paired")))
#  conclusion2<-atacPipe(fastqInput1 = bedbzfile11,fastqInput2 = bedbzfile12)
#  

## ----casecontrol, eval=FALSE---------------------------------------------
#  td<-tempdir()
#  options(atacConf=setConfigure("threads",4))
#  dir.create(file.path(td,"ref"))
#  # change the refdir to your installed refdir path
#  # or it will be time comsuming to build bowtie2 index
#  options(atacConf=setConfigure("refdir",file.path(td,"ref")))
#  options(atacConf=setConfigure("genome","hg19"))
#  case <- c(
#      system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#      system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz")
#  )
#  ctrl <- c(
#      system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2"),
#      system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")
#  )
#  conclusion<-atacPipe2(case=list(fastqInput1 = case[1],fastqInput2 = case[2]),

## ----Preprocess, warning = FALSE, results = 'hide', message = FALSE------
# Identify adapters
prefix<-system.file(package="esATAC", "extdata", "uzmg")
(reads_1 <-file.path(prefix,"m1",dir(file.path(prefix,"m1"))))
(reads_2 <-file.path(prefix,"m2",dir(file.path(prefix,"m2"))))

reads_merged_1 <- file.path(td,"reads1.fastq")
reads_merged_2 <- file.path(td,"reads2.fastq")
atacproc <- 
atacUnzipAndMerge(fastqInput1 = reads_1,fastqInput2 = reads_2) %>%
atacRenamer %>% atacRemoveAdapter

## ----adrmhelp------------------------------------------------------------
library(Rbowtie2)
adapterremoval_usage()

## ----Mapping, warning = FALSE, results = 'hide', message = FALSE---------
## Building a bowtie2 index
library("Rbowtie2")
refs <- dir(system.file(package="esATAC", "extdata", "bt2","refs"),
full=TRUE)
bowtie2_build(references=refs, bt2Index=file.path(td, "lambda_virus"),
"--threads 4 --quiet",overwrite=TRUE)
## Alignments
reads_1 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_1.fastq")
reads_2 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_2.fastq")
if(file.exists(file.path(td, "lambda_virus.1.bt2"))){
    (bowtie2Mapping(bt2Idx = file.path(td, "lambda_virus"),
       samOutput = file.path(td, "result.sam"),
       fastqInput1=reads_1,fastqInput2=reads_2,threads=3))
    head(readLines(file.path(td, "result.sam")))
}

## ----bt2help-------------------------------------------------------------
library(Rbowtie2)
bowtie2_usage()

## ----Convert, warning = FALSE, results = 'hide', message = FALSE---------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBed(samInput = samfile) 

## ----FiltCalling, warning = FALSE, results = 'hide', message = FALSE-----
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling


## ----echo = TRUE, results = 'hide', message = FALSE----------------------
## extract example peak file from package "esATAC"
p1bz <- system.file("extdata", "Example_peak1.bed.bz2", package="esATAC")
peak1_path <- as.vector(bunzip2(filename = p1bz,
destname = file.path(getwd(), "Example_peak1.bed"),
ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
## run peakanno to annotate peaks
AnnoInfo <- peakanno(peakInput = peak1_path, TxDb = TxDb.Hsapiens.UCSC.hg19.knownGene, annoDb = "org.Hs.eg.db")

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
library(ChIPseeker)

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
peakanno <- getReportVal(AnnoInfo, "annoOutput.rds")
plotAnnoPie(x = peakanno)

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
peakanno <- as.data.frame(peakanno)
colnames(peakanno)[1] <- "chromatin"
peakanno <- subset(peakanno, select=c("chromatin", "start", "end", 
                                      "annotation", "geneStart", "geneEnd", 
                                      "geneId", "distanceToTSS", "SYMBOL"))
knitr::kable(peakanno[1:5, ])

## ----eval = TRUE, echo = TRUE, results = 'hide', message = FALSE---------
## extract gene ID
library(clusterProfiler)
data(geneList)
geneId <- names(geneList)[1:100]
## do GO analysis
goAna <- goanalysis(gene = geneId, OrgDb = "org.Hs.eg.db", keytype = "ENTREZID", ont = "MF")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
go_path <- getReportVal(goAna, "goOutput")
go_data <- read.table(file = go_path, header = TRUE, sep = "\t")
go_data <- subset(go_data, select = c("ID", "Description", "GeneRatio", "pvalue", "qvalue"))
knitr::kable(go_data[1:5, ])

## ----eval=TRUE, echo=TRUE, warning=FALSE---------------------------------
pwm <- readRDS(system.file("extdata", "motifPWM.rds", package="esATAC"))

pwm

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  sample.path <- system.file("extdata", "chr20_sample_peak.bed.bz2", package="esATAC")
#  sample.path <- as.vector(bunzip2(filename = sample.path,
#  destname = file.path(getwd(), "chr20_sample_peak.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  motif.data <- motifscan(peak = sample.path, genome = BSgenome.Hsapiens.UCSC.hg19,
#  motifPWM = pwm, prefix = "test")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
CTCF.df <- data.frame(chromatin = c("chr20", "chr20", "chr20", "chr20"),
                      start = c("189774", "239773", "247783", "281074"), 
                      end = c("189792", "239791", "247801", "281092"), 
                      strand = c("+", "+", "-", "-"),
                      score = c("0.8794931", "0.9003697", "0.9337214", "0.8511201"), 
                      sequence = c("ACTCCTCTAGAGGGTGCTC", "TTGCCACTGGGGGGAGACA",
                      "CTGCCGGCAGATGGCGGTA", "TTGCCTGCAGGGGTGGGAA"))
knitr::kable(CTCF.df)

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  ## extract cut site position from bed file
#  fra_path <- system.file("extdata", "chr20.50000.bed.bz2", package="esATAC")
#  frag <- as.vector(bunzip2(filename = fra_path,
#  destname = file.path(getwd(), "chr20.50000.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  cs.data <- extractcutsite(bedInput = frag, prefix = "ATAC")

## ----eval=FALSE, echo=TRUE, warning=FALSE, results='hide', message=FALSE----
#  fp <- atacCutSiteCount(atacProcCutSite = cs.data, atacProcMotifScan = motif.data)

## ----printmap, warning=FALSE, message=FALSE------------------------------
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

peakproc <-bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling 

peakproc %>%  printMap


## ----qpara, warning=FALSE, message=FALSE---------------------------------
#query all of available parameters
getParamItems(peakproc)

## ----getpara, warning=FALSE, message=FALSE-------------------------------
#query a parameter value
getParam(peakproc,"fragmentSize")


## ----getReport, warning=FALSE, results='hide', message=FALSE-------------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBedProc<-samToBed(samInput = samfile)

## ----getReport1,message=FALSE--------------------------------------------
getReportItems(samToBedProc)

## ----getReport2,message=FALSE--------------------------------------------
#query a parameter value
getReportVal(samToBedProc,"report")


## ----clearcache, warning=FALSE, results='hide', message=FALSE------------
clearProcCache(peakproc)
process(peakproc)

## ----session-------------------------------------------------------------
sessionInfo()

==> esATAC_1.0.3.tar.gz: esATAC/inst/doc/ATACpipe-Introduction.R <==
## ----setup, include=FALSE------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, warning=FALSE, message=FALSE)

## ----flowchart,message=FALSE,warning=FALSE-------------------------------
library(esATAC)
printMap()

## ----querymannual,message=FALSE,warning=FALSE----------------------------
?atacSamToBed

## ----querymannual1,message=FALSE,warning=FALSE---------------------------
?samToBed

## ----installpkg,eval=FALSE,message=FALSE,warning=FALSE-------------------
#  source("http://www.bioconductor.org/biocLite.R")
#  biocLite("esATAC")

## ----loading0,message=FALSE----------------------------------------------
library(esATAC)

## ----loading1,message=FALSE----------------------------------------------
options(java.parameters = "-Xmx8000m")

## ----loadingpkg,message=FALSE--------------------------------------------
library(magrittr)
library(BSgenome.Hsapiens.UCSC.hg19)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(org.Hs.eg.db)
library(R.utils)

## ----loadref, eval=TRUE--------------------------------------------------
# we use temp directiory "td" here 
# Change it to your directiory because the intermediate file may be huge
td<-tempdir()
options(atacConf=setConfigure("tmpdir",td))
options(atacConf=setConfigure("threads",8))

## ----config, eval=TRUE---------------------------------------------------
#uncomment and modify to run:
#options(atacConf=setConfigure("refdir","path/to/refdatafolder"))
#options(atacConf=setConfigure("genome","hg19"))

## ----casecontrol, eval=FALSE---------------------------------------------
#  # set reference installation path
#  options(atacConf=setConfigure("refdir","your/reference/path"))
#  
#  # set reference genome like hg19, mm10 etc.
#  options(atacConf=setConfigure("genome","hg19"))
#  
#  # fastq files path
#  caseFastqs <- c(
#      system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz"),
#      system.file(package="esATAC", "extdata", "chr20_2.1.fq.gz")
#  )
#  ctrlFastqs <- c(
#      system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2"),
#      system.file(package="esATAC", "extdata", "chr20_2.2.fq.bz2")
#  )
#  
#  # call the esATAC pipeline
#  atacPipe2(case=list(fastqInput1 = case[1],fastqInput2 = case[2]),
#           control=list(fastqInput1 = ctrl[1],fastqInput2 = ctrl[2]))

## ----casesingle, eval=FALSE----------------------------------------------
#  # set reference installation path
#  options(atacConf=setConfigure("refdir","your/reference/path"))
#  
#  # set reference genome like hg19, mm10 etc.
#  options(atacConf=setConfigure("genome","hg19"))
#  
#  # fastq files path
#  mate1Fastq <- system.file(package="esATAC", "extdata", "chr20_1.1.fq.gz")
#  mate2Fastq <- system.file(package="esATAC", "extdata", "chr20_1.2.fq.bz2")
#  
#  # call the esATAC pipeline
#  conclusion <- atacPipe(fastqInput1 = mate1Fastq, fastqInput2 = mate2Fastq)

## ----motifsetex,eval=FALSE-----------------------------------------------
#  motiflist<-list("the pwms")
#  
#  
#  atacPipe2(case=list(fastqInput1 = case[1],fastqInput2 = case[2]),
#           control=list(fastqInput1 = ctrl[1],fastqInput2 = ctrl[2]),motifPWM = motiflist)
#  
#  
#  conclusion <- atacPipe(fastqInput1 = mate1Fastq, fastqInput2 = mate2Fastq,motifPWM = motiflist)

## ----Preprocess, warning = FALSE, results = 'hide', message = FALSE------
# Identify adapters
prefix<-system.file(package="esATAC", "extdata", "uzmg")
(reads_1 <-file.path(prefix,"m1",dir(file.path(prefix,"m1"))))
(reads_2 <-file.path(prefix,"m2",dir(file.path(prefix,"m2"))))

reads_merged_1 <- file.path(td,"reads1.fastq")
reads_merged_2 <- file.path(td,"reads2.fastq")
atacproc <- 
atacUnzipAndMerge(fastqInput1 = reads_1,fastqInput2 = reads_2) %>%
atacRenamer %>% atacRemoveAdapter

## ----adrmhelp------------------------------------------------------------
library(Rbowtie2)
adapterremoval_usage()

## ----Mapping, warning = FALSE, results = 'hide', message = FALSE---------
## Building a bowtie2 index
library("Rbowtie2")
refs <- dir(system.file(package="esATAC", "extdata", "bt2","refs"),
full=TRUE)
bowtie2_build(references=refs, bt2Index=file.path(td, "lambda_virus"),
"--threads 4 --quiet",overwrite=TRUE)
## Alignments
reads_1 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_1.fastq")
reads_2 <- system.file(package="esATAC", "extdata", "bt2", "reads",
"reads_2.fastq")
if(file.exists(file.path(td, "lambda_virus.1.bt2"))){
    (bowtie2Mapping(bt2Idx = file.path(td, "lambda_virus"),
       samOutput = file.path(td, "result.sam"),
       fastqInput1=reads_1,fastqInput2=reads_2,threads=3))
    head(readLines(file.path(td, "result.sam")))
}

## ----bt2help-------------------------------------------------------------
library(Rbowtie2)
bowtie2_usage()

## ----Convert, warning = FALSE, results = 'hide', message = FALSE---------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBed(samInput = samfile) 

## ----FiltCalling, warning = FALSE, results = 'hide', message = FALSE-----
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling


## ----echo = TRUE, results = 'hide', message = FALSE----------------------
## extract example peak file from package "esATAC"
p1bz <- system.file("extdata", "Example_peak1.bed.bz2", package="esATAC")
peak1_path <- as.vector(bunzip2(filename = p1bz,
destname = file.path(getwd(), "Example_peak1.bed"),
ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
## run peakanno to annotate peaks
AnnoInfo <- peakanno(peakInput = peak1_path, TxDb = TxDb.Hsapiens.UCSC.hg19.knownGene, annoDb = "org.Hs.eg.db")

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
library(ChIPseeker)

## ----eval = TRUE, echo = FALSE, warning = FALSE, results = 'hide', message = FALSE----
peakanno <- getReportVal(AnnoInfo, "annoOutput.rds")
plotAnnoPie(x = peakanno)

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
peakanno <- as.data.frame(peakanno)
colnames(peakanno)[1] <- "chromatin"
peakanno <- subset(peakanno, select=c("chromatin", "start", "end", 
                                      "annotation", "geneStart", "geneEnd", 
                                      "geneId", "distanceToTSS", "SYMBOL"))
knitr::kable(peakanno[1:5, ])

## ----eval = TRUE, echo = TRUE, results = 'hide', message = FALSE---------
## extract gene ID
library(clusterProfiler)
data(geneList)
geneId <- names(geneList)[1:100]
## do GO analysis
goAna <- goanalysis(gene = geneId, OrgDb = "org.Hs.eg.db", keytype = "ENTREZID", ont = "MF")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
go_path <- getReportVal(goAna, "goOutput")
go_data <- read.table(file = go_path, header = TRUE, sep = "\t")
go_data <- subset(go_data, select = c("ID", "Description", "GeneRatio", "pvalue", "qvalue"))
knitr::kable(go_data[1:5, ])

## ----eval=TRUE, echo=TRUE, warning=FALSE---------------------------------
pwm <- readRDS(system.file("extdata", "motifPWM.rds", package="esATAC"))

pwm

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  sample.path <- system.file("extdata", "chr20_sample_peak.bed.bz2", package="esATAC")
#  sample.path <- as.vector(bunzip2(filename = sample.path,
#  destname = file.path(getwd(), "chr20_sample_peak.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  motif.data <- motifscan(peak = sample.path, genome = BSgenome.Hsapiens.UCSC.hg19,
#  motifPWM = pwm, prefix = "test")

## ----eval = TRUE, echo = FALSE, warning = FALSE--------------------------
CTCF.df <- data.frame(chromatin = c("chr20", "chr20", "chr20", "chr20"),
                      start = c("189774", "239773", "247783", "281074"), 
                      end = c("189792", "239791", "247801", "281092"), 
                      strand = c("+", "+", "-", "-"),
                      score = c("0.8794931", "0.9003697", "0.9337214", "0.8511201"), 
                      sequence = c("ACTCCTCTAGAGGGTGCTC", "TTGCCACTGGGGGGAGACA",
                      "CTGCCGGCAGATGGCGGTA", "TTGCCTGCAGGGGTGGGAA"))
knitr::kable(CTCF.df)

## ----eval = FALSE, echo = TRUE, warning = FALSE, results = 'hide', message = FALSE----
#  ## extract cut site position from bed file
#  fra_path <- system.file("extdata", "chr20.50000.bed.bz2", package="esATAC")
#  frag <- as.vector(bunzip2(filename = fra_path,
#  destname = file.path(getwd(), "chr20.50000.bed"),
#  ext="bz2", FUN=bzfile, overwrite=TRUE, remove = FALSE))
#  cs.data <- extractcutsite(bedInput = frag, prefix = "ATAC")

## ----eval=FALSE, echo=TRUE, warning=FALSE, results='hide', message=FALSE----
#  fp <- atacCutSiteCount(atacProcCutSite = cs.data, atacProcMotifScan = motif.data)

## ----printmap, warning=FALSE, message=FALSE------------------------------
bedbzfile <- system.file(package="esATAC", "extdata", "chr20.50000.bed.bz2")
bedfile <- file.path(td,"chr20.50000.bed")
bunzip2(bedbzfile,destname=bedfile,overwrite=TRUE,remove=FALSE)

peakproc <-bedUtils(bedInput = bedfile,maxFragLen = 100, chrFilterList = NULL) %>%
atacPeakCalling 

peakproc %>%  printMap


## ----qpara, warning=FALSE, message=FALSE---------------------------------
#query all of available parameters
getParamItems(peakproc)

## ----getpara, warning=FALSE, message=FALSE-------------------------------
#query a parameter value
getParam(peakproc,"fragmentSize")


## ----getReport, warning=FALSE, results='hide', message=FALSE-------------
sambzfile <- system.file(package="esATAC", "extdata", "Example.sam.bz2")
samfile <- file.path(td,"Example.sam")
bunzip2(sambzfile,destname=samfile,overwrite=TRUE,remove=FALSE)
samToBedProc<-samToBed(samInput = samfile)

## ----getReport1,message=FALSE--------------------------------------------
getReportItems(samToBedProc)

## ----getReport2,message=FALSE--------------------------------------------
#query a parameter value
getReportVal(samToBedProc,"report")


## ----clearcache, warning=FALSE, results='hide', message=FALSE------------
clearProcCache(peakproc)
process(peakproc)

## ----session-------------------------------------------------------------
sessionInfo()
